export declare type ColumnAlign = 'left' | 'right' | 'center' | null;
export interface DropDownItem {
    value: string;
    label: string;
    disabled?: boolean;
    groupLabel?: string;
}
export interface TreeNode {
    key: string;
    title: string;
    isLeaf: boolean;
    children: TreeNode[];
}
export interface NumberKeyValueEntry {
    key: number;
    value: string;
}
export interface StringKeyValueEntry {
    key: string;
    value: string;
}
export interface ColumnValue {
    key: string;
    value: string;
    type: number;
    displayContent: string;
    color: string;
}
export interface ButtonValue {
    id: number;
    type: number;
    disabled: boolean;
    hidden: boolean;
}
export interface RowValue {
    id: number;
    checked: boolean;
    columnValueList: ColumnValue[];
    buttonValueList: ButtonValue[];
}
export interface TreeItemNode {
    id: number;
    name: string;
    valueList: ColumnValue[];
    children: TreeItemNode[];
}
export interface TreeItem {
    id: number;
    name: string;
    valueList: ColumnValue[];
    level: number;
    isLeaf: boolean;
    expandable: boolean;
    disabled: boolean;
}
export interface ColumnDefinition {
    id: number;
    sequence: number;
    name: string;
    title: string;
    type: number;
    visible: boolean;
    width: number;
    align: ColumnAlign;
    feature: string;
}
export interface FieldDefinition {
    id: number;
    sequence: number;
    name: string;
    title: string;
    type: number;
    visible: boolean;
    align: ColumnAlign;
    span: number;
}
export interface ButtonDefinition {
    id: number;
    title: string;
}
export interface TableLayoutParameter {
    mode: number;
    headerHeight: number;
    link: string;
}
export interface CardLayoutParameter {
    mode: number;
    headerHeight: number;
    link: string;
    cardHeight: number;
    cardWidth: number;
}
export interface TreeLayoutParameter {
    headerHeight: number;
    link: string;
}
export interface TreeTableLayoutParameter {
    mode: number;
    headerHeight: number;
    link: string;
}
export declare class ControlBase<T> {
    value: T | undefined;
    key: string;
    label: string;
    required: boolean;
    span: number;
    labelWidth: number;
    controlType: string;
    display: number;
    constructor(option?: {
        value?: T;
        key?: string;
        label?: string;
        required?: boolean;
        span?: number;
        display?: number;
        labelWidth?: number;
        controlType?: string;
    });
}
export declare class TextboxControl extends ControlBase<string> {
    maxLength: number;
    constructor(option?: {
        value?: string;
        key?: string;
        label?: string;
        required?: boolean;
        span?: number;
        labelWidth?: number;
        display?: number;
        maxLength?: number;
    });
}
export declare class TextareaControl extends ControlBase<string> {
    row: number;
    maxLength: number;
    constructor(option?: {
        value?: string;
        key?: string;
        label?: string;
        required?: boolean;
        span?: number;
        labelWidth?: number;
        display?: number;
        row?: number;
        maxLength?: number;
    });
}
export declare class IntegerControl extends ControlBase<number> {
    minValue: number;
    maxValue: number;
    constructor(option?: {
        value?: number;
        key?: string;
        label?: string;
        required?: boolean;
        span?: number;
        labelWidth?: number;
        display?: number;
        minValue?: number;
        maxValue?: number;
    });
}
export declare class DecimalControl extends ControlBase<number> {
    minValue: number;
    maxValue: number;
    percision: number;
    constructor(option?: {
        value?: number;
        key?: string;
        label?: string;
        required?: boolean;
        span?: number;
        labelWidth?: number;
        display?: number;
        minValue?: number;
        maxValue?: number;
        percision?: number;
    });
}
export declare class DatePickerControl extends ControlBase<Date> {
    format: string;
    allowClear: boolean;
    constructor(option?: {
        value?: Date;
        key?: string;
        label?: string;
        required?: boolean;
        span?: number;
        labelWidth?: number;
        display?: number;
        format?: string;
        allowClear?: boolean;
    });
}
export declare class DateTimePickerControl extends ControlBase<Date> {
    format: string;
    allowClear: boolean;
    constructor(option?: {
        value?: Date;
        key?: string;
        label?: string;
        required?: boolean;
        span?: number;
        labelWidth?: number;
        display?: number;
        format?: string;
        allowClear?: boolean;
    });
}
export declare class DropdownSingleControl extends ControlBase<string> {
    showSearch: boolean;
    allowClear: boolean;
    optionList: DropDownItem[];
    constructor(option?: {
        value?: string;
        key?: string;
        label?: string;
        required?: boolean;
        span?: number;
        labelWidth?: number;
        display?: number;
        showSearch?: boolean;
        allowClear?: boolean;
        optionList?: DropDownItem[];
    });
}
export declare class DropdownMultipleControl extends ControlBase<string[]> {
    showSearch: boolean;
    allowClear: boolean;
    optionList: DropDownItem[];
    maxCount: number;
    maxTagCount: number;
    constructor(option?: {
        value?: string[];
        key?: string;
        label?: string;
        required?: boolean;
        span?: number;
        labelWidth?: number;
        display?: number;
        maxCount?: number;
        maxTagCount?: number;
        showSearch?: boolean;
        allowClear?: boolean;
        optionList?: DropDownItem[];
    });
}
export declare class CascaderControl extends ControlBase<string[]> {
    showSearch: boolean;
    allowClear: boolean;
    optionTree: TreeNode[];
    constructor(option?: {
        value?: string[];
        key?: string;
        label?: string;
        required?: boolean;
        span?: number;
        labelWidth?: number;
        display?: number;
        showSearch?: boolean;
        allowClear?: boolean;
        optionTree?: TreeNode[];
    });
}
export declare class TreeSingleControl extends ControlBase<string> {
    showSearch: boolean;
    allowClear: boolean;
    optionTree: TreeNode[];
    constructor(option?: {
        value?: string;
        key?: string;
        label?: string;
        required?: boolean;
        span?: number;
        labelWidth?: number;
        display?: number;
        showSearch?: boolean;
        allowClear?: boolean;
        optionTree?: TreeNode[];
    });
}
export declare class TreeMultipleControl extends ControlBase<string[]> {
    showSearch: boolean;
    allowClear: boolean;
    optionTree: TreeNode[];
    maxCount: number;
    maxTagCount: number;
    constructor(option?: {
        value?: string[];
        key?: string;
        label?: string;
        required?: boolean;
        span?: number;
        labelWidth?: number;
        display?: number;
        maxCount?: number;
        maxTagCount?: number;
        showSearch?: boolean;
        allowClear?: boolean;
        optionTree?: TreeNode[];
    });
}
export declare class RadioControl extends ControlBase<string> {
    optionList: DropDownItem[];
    constructor(option?: {
        value?: string;
        key?: string;
        label?: string;
        required?: boolean;
        span?: number;
        labelWidth?: number;
        display?: number;
        showSearch?: boolean;
        optionList?: DropDownItem[];
    });
}
export declare class SwitchControl extends ControlBase<boolean> {
    checkedTitle: string;
    uncheckedTitle: string;
    constructor(option?: {
        value?: boolean;
        key?: string;
        label?: string;
        required?: boolean;
        span?: number;
        labelWidth?: number;
        display?: number;
        checkedTitle?: string;
        uncheckedTitle?: string;
    });
}
export declare class UploadImageControl extends ControlBase<UploadFile[]> {
    maxCount: number;
    constructor(option?: {
        value?: UploadFile[];
        key?: string;
        label?: string;
        required?: boolean;
        span?: number;
        labelWidth?: number;
        display?: number;
        maxCount?: number;
    });
}
export declare class UploadDocControl extends ControlBase<UploadFile[]> {
    maxCount: number;
    constructor(option?: {
        value?: UploadFile[];
        key?: string;
        label?: string;
        required?: boolean;
        span?: number;
        labelWidth?: number;
        display?: number;
        maxCount?: number;
    });
}
export declare class UploadImageBase64Control extends ControlBase<string[]> {
    maxCount: number;
    constructor(option?: {
        value?: string[];
        key?: string;
        label?: string;
        required?: boolean;
        span?: number;
        labelWidth?: number;
        display?: number;
        maxCount?: number;
    });
}
export declare class DividerControl extends ControlBase<string> {
    position: 'left' | 'right' | 'center';
    constructor(option?: {
        value?: string;
        key?: string;
        label?: string;
        required?: boolean;
        span?: number;
        display?: number;
        position?: 'left' | 'right' | 'center';
    });
}
export declare class TypographyControl extends ControlBase<string> {
    constructor(option?: {
        value?: string;
        key?: string;
        label?: string;
        required?: boolean;
        span?: number;
        display?: number;
        maxCount?: number;
    });
}
export interface InnerTableControl {
    title: string;
    tableHeight: number;
    tableWidth: number;
    columnDefinitionList: ColumnDefinition[];
    rowValueList: RowValue[];
}
export interface UploadFile {
    name: string;
    size: number;
    type: string;
    content: string;
}
export interface CommonResponse {
    errcode: number;
    errmsg: string;
}
export interface NumberKeyValueNode {
    key: number;
    value: string;
    fullContent?: string;
    children?: NumberKeyValueNode[];
}
export declare class FilterBase<T> {
    value: T | undefined;
    key: string;
    label: string;
    required: boolean;
    span: number;
    controlType: string;
    display: number;
    constructor(option?: {
        value?: T;
        key?: string;
        label?: string;
        required?: boolean;
        span?: number;
        display?: number;
        controlType?: string;
    });
}
